@@ -288,7 +288,7 @@ wget
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-streamFinder-iheartradio at rt.cpan.org>, or through
+Please report any bugs or feature requests to C<bug-streamFinder-subsplash at rt.cpan.org>, or through
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=StreamFinder-Subsplash>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
@@ -310,10 +310,6 @@ L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=StreamFinder-Subsplash>
 
 L<http://annocpan.org/dist/StreamFinder-Subsplash>
 
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/StreamFinder-Subsplash>
-
 =item * Search CPAN
 
 L<http://search.cpan.org/dist/StreamFinder-Subsplash/>
